@@ -1,3 +1,4 @@
+use strict; use warnings;
 package Term::ReadLine::Perl5::Tie;
 
 sub TIEHASH { bless {} }
@@ -5,6 +6,7 @@ sub TIEHASH { bless {} }
 sub STORE {
   my ($self, $name) = (shift, shift);
   no strict;
+  no warnings 'once';
   $ {'Term::ReadLine::Perl5::readline::rl_' . $name} = shift;
 }
 
